@@ -1,4 +1,4 @@
-#![doc(html_root_url = "https://docs.rs/inv-sys/1.2.2")]
+#![doc(html_root_url = "https://docs.rs/inv-sys/1.3.0")]
 
 use std::fmt::Debug;
 
@@ -69,6 +69,11 @@ where T: Stacksize + Eq + Clone {
 		}
 	}
 
+	/// Returns the optional ItemStack in the Slot
+	pub fn inner(&self) -> &Option<ItemStack<T>> {
+		&self.inner
+	}
+
 	/// Returns the item in the Slot
 	pub fn get_item(&self) -> Result<&T, InvAccessErr> {
 		if let Some(inner) = &self.inner {
